@@ -1,5 +1,4 @@
-import sys
-import os
+import sys, os
 from pathlib import Path
 
 currentDirectory = os.getcwd()
@@ -14,7 +13,13 @@ sys.path.append(eventPublisherDirectory)
 #sys.path.append(settingsDirectory)
 #sys.path.append(absolutePath)
 
-import EventHub.SendEvents as SendEvents
+# change the current directory so we can read the settings.json
+os.chdir(eventPublisherDirectory)
 
-SendEvents.run_send_events('order.create', 'Development', 'fla-105-code', 'fla-105', '[{"entityId":"a"}]')
-#Environment.set_environment()
+import EventHub.SendEvents as SendEvents
+import EventPublisher.Publisher as Publisher
+
+json = '{"environment":"Development", "eventType":"OrderWrittenSale", "clientCode":"fla-105-code", "accountName":"fla-105", "data":[{"entityId":"a"}]}'
+
+respose = Publisher.run(json)
+print(respose)
\ No newline at end of file
